import { Stack, Typography } from "@mui/material";
import {
  PlayCircleFilled,
  PauseCircleFilled,
  AddCircleOutline,
  RemoveCircleOutline
} from "@mui/icons-material";

import { ReactComponent as BatchDeployIconSvg } from "../../icons/batch_deploy_icon.svg";
import { ReactComponent as BatchUndeployIconSvg } from "../../icons/batch_undeploy_icon.svg";

const batchIconDefaultProps = { width: "25px", height: "25px" };

export const StartIcon = ({ ...props }) => <PlayCircleFilled {...props} />;
export const StopIcon = ({ ...props }) => <PauseCircleFilled {...props} />;
export const DeployIcon = ({ ...props }) => <AddCircleOutline {...props} />;
export const UndeployIcon = ({ ...props }) => (
  <RemoveCircleOutline {...props} />
);
export const BatchDeployIcon = ({ ...props }) => (
  <BatchDeployIconSvg
    {...batchIconDefaultProps}
    {...props}
  />
);
export const BatchUndeployIcon = ({ ...props }) => (
  <BatchUndeployIconSvg
    {...batchIconDefaultProps}
    {...props}
  />
);

export const JOB_TYPES = {
  DEPLOY: "DEPLOY",
  UNDEPLOY: "UNDEPLOY",
  BATCH_DEPLOY: "BATCH_DEPLOY",
  BATCH_UNDEPLOY: "BATCH_UNDEPLOY",
  START: "START",
  STOP: "STOP"
};

export const JobTypesComponent = {
  DEPLOY: {
    label: "Deployment",
    icon: DeployIcon
  },
  UNDEPLOY: {
    label: "Undeployment",
    icon: UndeployIcon
  },
  BATCH_DEPLOY: {
    label: "Batch deployment",
    icon: BatchDeployIcon
  },
  BATCH_UNDEPLOY: {
    label: "Batch undeployment",
    icon: BatchUndeployIcon
  },
  START: {
    label: "Set active",
    icon: StartIcon
  },
  STOP: {
    label: "Set inactive",
    icon: StopIcon
  }
};

interface JobTypeIconTextProps {
  type: string | undefined;
}

export interface JobType {
  DEPLOY: string;
  UNDEPLOY: string;
  BATCH_DEPLOY: string;
  BATCH_UNDEPLOY: string;
  START: string;
  STOP: string;
}

export const JobTypeIconText = ({ type }: JobTypeIconTextProps) => {
  const Icon = JobTypesComponent[type as keyof JobType].icon;

  return (
    <Stack
      flexDirection="row"
      alignItems="center"
      gap="5px"
      sx={{ width: "100%" }}
    >
      <Icon
        width="24px"
        height="24px"
      />
      <Typography>{JobTypesComponent[type as keyof JobType].label}</Typography>
    </Stack>
  );
};
